#[repr(transparent)]pub struct NotificationsPage {
inner: TypedObjectRef<NotificationsPage, <NotificationsPage as ObjectSubclass>::ParentType>,
phantom: PhantomData<()>,
}Expand description
Preferences page to edit global notification settings.
GLib type: GObject with reference counted clone semantics.
Fields
inner: TypedObjectRef<NotificationsPage, <NotificationsPage as ObjectSubclass>::ParentType>phantom: PhantomData<()>Implementations
Sourceimpl NotificationsPage
impl NotificationsPage
Sourcepub fn notifications_settings(
&self,
) -> <BoundObjectWeakRef<NotificationsSettings> as Property>::Value
pub fn notifications_settings( &self, ) -> <BoundObjectWeakRef<NotificationsSettings> as Property>::Value
The notifications settings of the current session.
Sourcepub fn set_notifications_settings<'a>(
&self,
value: impl Borrow<<<BoundObjectWeakRef<NotificationsSettings> as Property>::Value as HasParamSpec>::SetValue>,
)
pub fn set_notifications_settings<'a>( &self, value: impl Borrow<<<BoundObjectWeakRef<NotificationsSettings> as Property>::Value as HasParamSpec>::SetValue>, )
The notifications settings of the current session.
Sourcepub fn account_loading(&self) -> <Cell<bool> as Property>::Value
pub fn account_loading(&self) -> <Cell<bool> as Property>::Value
Whether the account section is busy.
Sourcepub fn global_loading(&self) -> <Cell<bool> as Property>::Value
pub fn global_loading(&self) -> <Cell<bool> as Property>::Value
Whether the global section is busy.
Sourcepub fn global_setting(&self) -> <PhantomData<String> as Property>::Value
pub fn global_setting(&self) -> <PhantomData<String> as Property>::Value
The global notifications setting, as a string.
Sourcepub fn set_global_setting<'a>(
&self,
value: impl Borrow<<<PhantomData<String> as Property>::Value as HasParamSpec>::SetValue>,
)
pub fn set_global_setting<'a>( &self, value: impl Borrow<<<PhantomData<String> as Property>::Value as HasParamSpec>::SetValue>, )
The global notifications setting, as a string.
Sourcepub fn connect_notifications_settings_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_notifications_settings_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the notifications-settings property
Sourcepub fn connect_account_loading_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_account_loading_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the account-loading property
Sourcepub fn connect_global_loading_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_global_loading_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the global-loading property
Sourcepub fn connect_global_setting_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_global_setting_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the global-setting property
Sourcepub fn notify_notifications_settings(&self)
pub fn notify_notifications_settings(&self)
Notify listeners of a change in the notifications-settings property
Sourcepub fn notify_account_loading(&self)
pub fn notify_account_loading(&self)
Notify listeners of a change in the account-loading property
Sourcepub fn notify_global_loading(&self)
pub fn notify_global_loading(&self)
Notify listeners of a change in the global-loading property
Sourcepub fn notify_global_setting(&self)
pub fn notify_global_setting(&self)
Notify listeners of a change in the global-setting property
Sourceimpl NotificationsPage
impl NotificationsPage
pub fn new(notifications_settings: &NotificationsSettings) -> Self